@@ -120,11 +120,19 @@ class OTPRequestCodeSerializer(OTPSerializerMixin, serializers.ModelSerializer):
                 f"User with this {self.otp_sub_message} requested OTP code twice."
             )
             # TODO: Add time count down
+            seconds_left = (
+                timedelta(seconds=getattr(settings, "OTP_TIMEOUT", 3 * 60))
+                - (
+                    now()
+                    - OneTruePairing.objects.filter(**filter_kwargs).last().created_at
+                )
+            ).total_seconds()
+            minutes_left = int(seconds_left) // 60 or 1
             raise serializers.ValidationError(
                 _(
                     "We sent a verification code please wait for "
-                    "2 minutes; before requesting a new code."
-                )
+                    "{minutes} minutes; before requesting a new code."
+                ).format(minutes=minutes_left)
             )
 
     def validate(self, attrs: typing.Dict) -> typing.Dict:
